// Cosmo 3.1.1
// Bootswatch
// -----------------------------------------------------

@import url("//fonts.googleapis.com/css?family=Open+Sans:400italic,700italic,400,700");

// Navbar =====================================================================

.navbar {

  &-inverse {

    .badge {
      background-color: #fff;
      color: @brand-primary;
    }
  }
}

// Buttons ====================================================================

.btn-lg {
  padding-top: 19px;
}

// Typography =================================================================

.text-primary,
.text-primary:hover {
  color: @brand-primary;
}

.text-success,
.text-success:hover {
  color: @brand-success;
}

.text-danger,
.text-danger:hover {
  color: @brand-danger;
}

.text-warning,
.text-warning:hover {
  color: @brand-warning;
}

.text-info,
.text-info:hover {
  color: @brand-info;
}

// Tables =====================================================================

table,
.table {

  a {
    text-decoration: underline;
  }

  .success,
  .warning,
  .danger,
  .info {
    color: #fff;

    a {
      color: #fff;
    }
  }
}

// Forms ======================================================================


.has-warning {
  .help-block,
  .control-label,
  .form-control-feedback {
    color: @brand-warning;
  }

  .form-control,
  .form-control:focus {
    border: 1px solid @brand-warning;
  }
}

.has-error {
  .help-block,
  .control-label,
  .form-control-feedback {
    color: @brand-danger;
  }

  .form-control,
  .form-control:focus {
    border: 1px solid @brand-danger;
  }
}

.has-success {
  .help-block,
  .control-label,
  .form-control-feedback {
    color: @brand-success;
  }

  .form-control,
  .form-control:focus {
    border: 1px solid @brand-success;
  }
}

// Navs =======================================================================

.nav-pills {

  & > li > a {
    border-radius: 0;
  }
}

.dropdown-menu {

  & > li > a:hover,
  & > li > a:focus {
    background-image: none;
  }
}

// Indicators =================================================================

.alert {
  border: none;

  .alert-link {
    text-decoration: underline;
    color: #fff;
  }

  .close {
    color: #fff;
    text-decoration: none;
    opacity: 0.4;

    &:hover,
    &:focus {
      color: #fff;
      opacity: 1;
    }
  }
}

.label {
  border-radius: 0;
}

// Progress bars ==============================================================

.progress {
  height: 8px;
  .box-shadow(none);
  .progress-bar {
    font-size: 8px;
    line-height: 8px;
  }
}

// Containers =================================================================

.panel {
  &-heading,
  &-footer {
    border-top-right-radius: 0;
    border-top-left-radius: 0;
  }
}
